#!/usr/bin/perl
# Script to take lastcomm output as input, and generate
# .data files for commands and users found in that input.
# Written 2002-01-27 by Jim Lippard.
# Modified 2012-12-21 by Jim Lippard to add -t option.

# Use lastcomm to pipe data into this script,
#     i.e., lastcomm | accollect.pl [-t <start_time>]

# -t option will stop collecting data at the specified start time.

### Requirements, packages.

use strict;
use Getopt::Std;
use ProcessAccounting;
use Time::ParseDate;

### Variables.

my (%options, $start_time, $lastcomm);

### Program.

# Get options.
getopts ('t:', \%options);

$start_time = 0;

if ($options{'t'}) {
    $start_time = $options{'t'};
    $start_time = parsedate ($start_time);
}

while (<STDIN>) {
    chop;
    $lastcomm = ProcessAccounting::parseline ($_);

# This causes acct_monitor.pl to abort. 
#    last if ($lastcomm->{time} <= $start_time);

    # Collect raw data.
    &add_to_data ($lastcomm) if ($lastcomm->{time} > $start_time);
}
exit;

sub add_to_data {
    my ($lastcomm) = @_;
    my ($command, $user);

    $command = $lastcomm->{command};
    $user = $lastcomm->{user};

    # Command data.
    &ProcessAccounting::write_command_data ("$command.data", $lastcomm);

    # User data.
    &ProcessAccounting::write_user_data ("$user.data", $lastcomm);

    # Don't need to collect user command data--all of that information is in the user data.
}
