#!/usr/bin/perl
# Script to convert .data files to use durations in seconds instead of HH:MM:SS format.
# Written 2004-01-19 by Jim Lippard.

### Requirements, packages.

use strict;
use ProcessAccounting;

### Constants.

my $COMMAND = 1;
my $USER = 2;

my $STATS_DIR = '/home/lippard/stats';

### Variables.

my (@files, $file, $stat_file, $data, $user, @commands, $command);

### Program.

# Command data.
@files = &ProcessAccounting::list_command_data;

foreach $file (@files) {
    &convert_data ($file, $COMMAND);
}

# User data.
@files = &ProcessAccounting::list_user_data;

foreach $file (@files) {
    &convert_data ($file, $USER);
}

sub convert_data {
    my ($file, $type) = @_;
    my ($tempfile, $field1, $field2, $field3, $field4, $field5, $duration);

    if ($type == $COMMAND) {
	open (FILE, "$STATS_DIR/commands/$file") || die "Cannot open file $STATS_DIR/commands/$file.\n";
    }
    elsif ($type == $USER) {
	open (FILE, "$STATS_DIR/users/$file") || die "Cannot open file $STATS_DIR/users/$file.\n";
    }

    $tempfile = `/usr/bin/mktemp -t acconvert.XXXXXX`;
    chop ($tempfile);

    open (TEMP, ">$tempfile") || die "Cannot open file $tempfile.\n";

    while (<FILE>) {
	($field1, $field2, $field3, $field4, $field5, $duration) = split (/,\s+/);
	if ($duration =~ /:/) {
	    $duration = &ProcessAccounting::_duration_seconds ($duration);
	}
	print TEMP "$field1, $field2, $field3, $field4, $field5, $duration\n";
    }

    close (TEMP);
    close (FILE);

    if ($type == $COMMAND) {
	system "/bin/cp $tempfile $STATS_DIR/commands/$file";
    }
    elsif ($type == $USER) {
	system "/bin/cp $tempfile $STATS_DIR/users/$file";
    }

    unlink $tempfile;
}
