#!/usr/bin/perl
# Script to take .data files from accollect, identify aggregate
# statistics, and generate .stat files as output.
#
# If used with -m, new data from .data files is merged with existing .stat
# files, after which you will want to delete the .data files or the next
# use of -m will duplicate data (or next use without -m will wipe out
# old .stat data).
#    Note this means if you keep the data files, don't use -m when you
# update, which will re-create .stat files from all of your data.
#
# Written 2002-02-05 by Jim Lippard.
# Modified 2012-12-20 by Jim Lippard to fix bugs in -m.

# FINISH WRITING MERGE CODE FOR USER DATA.

### Requirements, packages.

use strict;
use Getopt::Std;
use ProcessAccounting;

### Variables.

my (%options, $merge, @files, $file, $stat_file, $data, $first_file, $system_stat, $old_stat, $user, %known_system_commands, $command);

### Program.

# Get options.
getopts ('m', \%options);

if ($#ARGV >= 0) {
    die "Usage: acstats.pl [-m]\n";
}

if ($options{'m'}) {
    $merge = 1;
}
else {
    $merge = 0;
}

# Command data.
@files = &ProcessAccounting::list_command_data;

$first_file = 1;

foreach $file (@files) {
    $data = &ProcessAccounting::read_command_data ($file);
    $stat_file = $file;
    $stat_file =~ s/\.data$/.stat/;
    if ($merge && &ProcessAccounting::exists_command_stat ($stat_file)) {
	$old_stat = &ProcessAccounting::read_command_stat ($stat_file);
	$data = &ProcessAccounting::merge_command_stats ($old_stat, $data);
    }
    &ProcessAccounting::write_command_stat ($stat_file, $data);

    $command = $stat_file;
    $command =~ s/\.stat$//;
    $known_system_commands{$command} = 1;
    if ($first_file) {
	$system_stat = $data;
	$first_file = 0;
    }
    else {
	$system_stat = &ProcessAccounting::merge_system_stats ($system_stat, $data);
    }
}

# Add known system commands.
foreach $command (keys (%known_system_commands)) {
    push (@{$system_stat->{commands}}, $command);
}

&ProcessAccounting::write_system_stat ($system_stat);

# User data.
@files = &ProcessAccounting::list_user_data;

foreach $file (@files) {
    $data = &ProcessAccounting::read_user_data ($file);
    $stat_file = $file;
    $stat_file =~ s/\.data$/.stat/;
    if ($merge && &ProcessAccounting::exists_user_stat ($stat_file)) {
	$old_stat = &ProcessAccounting::read_user_stat ($stat_file);
	$data = &ProcessAccounting::merge_user_stats ($old_stat, $data);
    }
    &ProcessAccounting::write_user_stat ($stat_file, $data);

    # User command data.  We get it from the user data files rather than duplicate
    # data yet again.
    $user = $file;
    $user =~ s/\.data$//;
    foreach $command (@{$data->{commands}}) {
	if ($command eq "") {
	    next;
	}
	$data = &ProcessAccounting::read_user_command_data ($file, $command);
	if ($merge && &ProcessAccounting::exists_user_command_stat ($command)) {
	    $old_stat = &ProcessAccounting::read_user_command_stat ($user, $command);
	    $data = &ProcessAccounting::merge_user_command_stats ($old_stat, $data);
	}
	&ProcessAccounting::write_user_command_stat ($user, "$command.stat", $data);
    }
}
